@@ -10,10 +10,8 @@ _HELP_MESSAGE_BINARY = """
     After extracting the binaries, the open source and license information of the saved binaries are retrieved by comparing the similarity
     with the binaries stored in the Binary DB (FOSSLight > Binary DB) with the Binary's TLSH (Trend micro Locality Sensitive Hash).
 
-    Mandatory:
-        -p <binary_path>\t\t    Path to analyze binaries
-
     Options:
+        -p <binary_path>\t\t    Path to analyze binaries (Default: current directory)
         -h\t\t\t\t    Print help message
         -v\t\t\t\t    Print FOSSLight Binary Scanner version
         -o <output_path>\t\t    Output path
