@@ -10,11 +10,11 @@ from datetime import datetime
 from binaryornot.check import is_binary
 import magic
 import logging
-import platform
 import yaml
 import stat
 from fosslight_util.help import print_package_version
 from fosslight_util.set_log import init_log
+from fosslight_util.timer_thread import TimerThread
 import fosslight_util.constant as constant
 from fosslight_util.write_txt import write_txt_file
 from fosslight_util.output_format import check_output_format, write_output_file
@@ -191,7 +191,10 @@ def find_binaries(path_to_find_bin, output_dir, format, dburl=""):
 
     try:
         if success_to_write:
-            logger.info(f"Output file :{result_file}")
+            if result_file:
+                logger.info(f"Output file :{result_file}")
+            else:
+                logger.warning(f"{writing_msg}")
         else:
             logger.error(f"Fail to generate result file.:{writing_msg}")
 
@@ -277,7 +280,7 @@ def main():
     global windows
     argv = sys.argv[1:]
     output_dir = ""
-    path_to_find_bin = ""
+    path_to_find_bin = os.getcwd()
     format = ""
     db_url = ""
 
@@ -290,6 +293,8 @@ def main():
                 print_package_version(_PKG_NAME, "FOSSLight Binary Scanner Version:")
             elif opt == "-p":
                 path_to_find_bin = arg
+                if not path_to_find_bin:
+                    path_to_find_bin = os.getcwd()
             elif opt == "-o":
                 output_dir = arg
             elif opt == "-f":
@@ -299,12 +304,9 @@ def main():
     except Exception:
         print_help_msg()
 
-    windows = platform.system() == "Windows"
-    if path_to_find_bin == "":
-        if windows:
-            path_to_find_bin = os.getcwd()
-        else:
-            print_help_msg()
+    timer = TimerThread()
+    timer.setDaemon(True)
+    timer.start()
 
     find_binaries(path_to_find_bin, output_dir, format, db_url)
 
